.. _transition-openwayback:

OpenWayback Transition Guide
============================

This guide provides guidelines for transtioning from OpenWayback to pywb,
with additional recommendations. The main recommendation is to run pywb along
with OutbackCDX and nginx, and this configuration is covered below, along with additional options.


.. toctree::
   :maxdepth: 2

   owb-pywb-terms 
   outbackcdx
   migrating-cdx
   owb-to-pywb-config
   owb-to-pywb-exclusions
   owb-to-pywb-deploy
 

